@@ -4,13 +4,13 @@
 # -- SOAP::Lite -- soaplite.com -- Copyright (C) 2001 Paul Kulchenko --
 
 use SOAP::Lite +autodispatch => 
-  uri => 'http://soaplite.com/My/Examples', 
+  uri => 'http://www.soaplite.com/My/Examples', 
   proxy => 'http://localhost/', 
 # proxy => 'http://localhost/cgi-bin/soap.cgi', # local CGI server
 # proxy => 'http://localhost/',                 # local daemon server
 # proxy => 'http://localhost/soap',             # local mod_perl server
 # proxy => 'https://localhost/soap',            # local mod_perl SECURE server
-# proxy => 'tcp:localhost:82',                  # local tcp server
+# proxy => 'tcp://localhost:82',                # local tcp server
   on_fault => sub { my($soap, $res) = @_; 
     die ref $res ? $res->faultdetail : $soap->transport->status, "\n";
   }
